@@ -70,7 +70,7 @@ class Graph:
     _outgoing_edges: ImmutableDict[Node, ImmutableSet[Edge]]
     _resources: ImmutableDict[str, Resource]
     _participants: ImmutableDict[str, Participant]
-    _major_claim: t.Optional[Node]
+    _major_claim: t.Optional[AtomNode]
     analysts: t.List[Participant]
     version: str
     created: pendulum.DateTime
@@ -171,7 +171,7 @@ class Graph:
         return self._resources
 
     @property
-    def major_claim(self) -> t.Optional[Node]:
+    def major_claim(self) -> t.Optional[AtomNode]:
         if self._major_claim:
             return self._major_claim
 
@@ -190,7 +190,10 @@ class Graph:
         return None
 
     @major_claim.setter
-    def major_claim(self, value: t.Optional[Node]) -> None:
+    def major_claim(self, value: t.Optional[AtomNode]) -> None:
+        if not (value is None or isinstance(value, AtomNode)):
+            raise TypeError(utils.type_error(type(value), AtomNode))
+
         self._major_claim = value
         # self._metadata.update()
 
@@ -503,19 +506,30 @@ class Graph:
             if node.participant == participant:
                 node.participant = None
 
-    # Muss man hier nicht auch noch den zweiten Node als Node Objekt definieren?
-    def node_distance(self, node1: Node, node2) -> t.Optional[int]:
-        """If node is in the graph, return the distance to the major claim (if set).
+    def node_distance(
+        self,
+        start_node: Node,
+        end_node: Node,
+        max_distance: t.Optional[int] = None,
+        directed: bool = True,
+    ) -> t.Optional[int]:
+        """Get the distance between `start_node` and `end_node` in the graph.
 
         Args:
-            node1: Node object that is part of the graph.
-            node2: Node object that is part of the graph.
+            start_node: Node object that is part of the graph.
+            end_node: Node object that is part of the graph.
+            max_distance: Only search for nodes having at most a distance of this argument.
+                Especially helpful when dealing with large graphs where shorts paths are searched for.
+            directed: If `False`, also search for the direction `end_node` -> `start_node`.
+
+        Returns:
+            `None` if no path between
 
         Examples:
             >>> import arguebuf
             >>> g = arguebuf.Graph("Test")
             >>> n1 = arguebuf.AtomNode("Node1")
-            >>> n2 = arguebuf.AtomNode("Node2")
+            >>> n2 = arguebuf.SchemeNode(arguebuf.SchemeType.SUPPORT)
             >>> n3 = arguebuf.AtomNode("Node3")
             >>> e1 = arguebuf.Edge(n1, n2)
             >>> e2 = arguebuf.Edge(n2, n3)
@@ -529,18 +543,25 @@ class Graph:
             2
             >>> g.node_distance(n1, n3)
             2
+            >>> g.node_distance(n3, n1)
+            None
         """
 
-        # TODO: Currently, there is no differentiation between I-nodes and S-nodes.
-
-        if node1 in self.nodes.values() and node2 in self.nodes.values():
-            if node1 == node2:
+        if start_node in self.nodes.values() and end_node in self.nodes.values():
+            if start_node == end_node:
                 return 0
 
-            return _node_distance(node1, node2, self._incoming_nodes) or _node_distance(
-                node1, node2, self._outgoing_nodes
+            dist = _node_distance(
+                start_node, end_node, self._outgoing_nodes, max_distance
             )
 
+            if dist is None and not directed:
+                dist = _node_distance(
+                    end_node, start_node, self._outgoing_nodes, max_distance
+                )
+
+            return dist
+
         return None
 
     @classmethod
@@ -579,7 +600,7 @@ class Graph:
             )
             g.add_node(node)
 
-            if ova_node.get("major_claim"):
+            if ova_node.get("major_claim") and isinstance(node, AtomNode):
                 g._major_claim = node
 
         for edge in obj["edges"]:
@@ -737,8 +758,10 @@ class Graph:
         for edge_id, edge in obj.edges.items():
             g.add_edge(edge_class.from_protobuf(edge_id, edge, g._nodes))
 
-        if major_claim := obj.major_claim:
-            g._major_claim = g._nodes[major_claim]
+        major_claim = g._nodes[obj.major_claim] if obj.major_claim else None
+
+        if major_claim and isinstance(major_claim, AtomNode):
+            g._major_claim = major_claim
 
         g.analysts = [
             participant_class.from_protobuf(utils.unique_id(), analyst)
@@ -1073,14 +1096,19 @@ class Graph:
 
 
 def _node_distance(
-    node1: Node, node2: Node, connections: t.Mapping[Node, t.Iterable[Node]]
+    node1: Node,
+    node2: Node,
+    connections: t.Mapping[Node, t.Iterable[Node]],
+    max_distance: t.Optional[int],
 ) -> t.Optional[int]:
     expansion: t.List[t.Tuple[Node, int]] = [(n, 1) for n in connections[node1]]
 
     while len(expansion) > 0:
         candidate, distance = expansion.pop()
 
-        if candidate == node2:
+        if max_distance is not None and distance > max_distance:
+            continue
+        elif candidate == node2:
             return distance
         else:
             expansion.extend((n, distance + 1) for n in connections[candidate])
